#
#    <pytcpwrap - Python wrapper for libwrap used for hosts.allow/hosts.deny access control>
#    Copyright (C) <2004>  <Eugene Coetzee>
#
#    This library is free software; you can redistribute it and/or
#    modify it under the terms of the GNU Lesser General Public
#    License as published by the Free Software Foundation; either
#    version 2.1 of the License, or (at your option) any later version.
#
#    This library is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#    Lesser General Public License for more details.
#
#    You should have received a copy of the GNU Lesser General Public
#    License along with this library; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#   e-mail author : eugene@reedflute.com
#   postal address   : Dwarsstreet 75, Potchefstroom,NW Province, 2531, Rebublic of South Africa		
#
version_info = (0,2,0)
__version__ = "0.2.0"

