from distutils.core import setup, Extension

module1 = Extension('libtcpwrap',
                    define_macros = [('MAJOR_VERSION', '0'),
                                     ('MINOR_VERSION', '2')],
                    include_dirs = ['/usr/local/include'],
                    libraries = ['wrap'],
                    library_dirs = ['/usr/local/lib'],
                    sources = ['pytcpwrap.c'])

setup (name = 'pytcpwrap',
       version = '0.2',
       description = 'TCP wrappers interface for Python',
       packages = ['pytcpwrap'],
       license = "LGPL",
       author = 'Eugene Coetzee',
       author_email = 'eugene@reedflute.com',
       url = 'http://ples.sf.net/PlesUtils',
       long_description = '''
Python interface to TCP wrappers libwrap
''',
       ext_modules = [module1])

