# Test program example for pytcpwrap
# TCPWrap wraps function hosts_ctl()
# for more documentation see man hosts_access(3)

# Note : Deny() and Allow() are checking for the same thing 
# and the two different functions are provided for convenience

from pytcpwrap.tcpwrap import TCPWrap 

print TCPWrap("progname","hostname","192.168.0.33").Deny()

print TCPWrap("progname","hostname","192.168.0.33").Allow()

